const colors: Record<string, string> = {
  critical: "bg-red-900 text-red-300",
  high: "bg-orange-900 text-orange-300",
  medium: "bg-slate-700 text-slate-300",
  low: "bg-gray-800 text-gray-400",
};

export default function PriorityBadge({ priority }: { priority: string }) {
  const cls = colors[priority] || "bg-slate-700 text-slate-300";
  return (
    <span
      className={`inline-block rounded-full px-2.5 py-0.5 text-xs font-medium ${cls}`}
    >
      {priority}
    </span>
  );
}
