export interface Project {
  id: string;
  path: string;
  created_at: string;
}

export interface Feature {
  id: number;
  project_id: string;
  name: string;
  description: string;
  status: "planned" | "in_progress" | "done" | "cancelled";
  created_at: string;
  updated_at: string;
}

export interface Task {
  id: number;
  project_id: string;
  title: string;
  description: string;
  priority: "low" | "medium" | "high" | "critical";
  status: "todo" | "in_progress" | "done" | "cancelled";
  commit_base: string;
  commit_head: string;
  created_at: string;
  updated_at: string;
}

export interface WorkLog {
  id: number;
  task_id: number;
  project_id: string;
  summary: string;
  files_changed: string;
  test_result: "" | "pass" | "fail" | "skip";
  created_at: string;
}

export interface ProjectStats {
  feature_counts: Record<string, number>;
  task_counts: Record<string, number>;
  task_priority_counts: Record<string, number>;
  total_logs: number;
  test_counts: Record<string, number>;
  recent_logs: WorkLog[];
}
