const colors: Record<string, string> = {
  planned: "bg-slate-700 text-slate-200",
  todo: "bg-slate-700 text-slate-200",
  in_progress: "bg-blue-900 text-blue-300",
  done: "bg-emerald-900 text-emerald-300",
  cancelled: "bg-stone-700 text-stone-300",
};

export default function StatusBadge({ status }: { status: string }) {
  const cls = colors[status] || "bg-slate-700 text-slate-200";
  return (
    <span
      className={`inline-block rounded-full px-2.5 py-0.5 text-xs font-medium ${cls}`}
    >
      {status.replace("_", " ")}
    </span>
  );
}
