import { Outlet } from "react-router-dom";
import Sidebar from "./Sidebar";
import StatusBar from "./StatusBar";

export default function Layout() {
  return (
    <div className="flex min-h-screen bg-[#000] text-[#ededed]">
      <Sidebar />
      <main className="flex-1 overflow-auto p-8">
        <Outlet />
      </main>
      <StatusBar />
    </div>
  );
}
