import { Routes, Route } from "react-router-dom";
import Layout from "./components/Layout";
import ProjectListPage from "./components/ProjectListPage";
import Dashboard from "./components/Dashboard";
import FeaturesPage from "./components/FeaturesPage";
import TasksPage from "./components/TasksPage";
import WorkLogsPage from "./components/WorkLogsPage";

export default function App() {
  return (
    <Routes>
      <Route path="/" element={<ProjectListPage />} />
      <Route path="/projects/:id" element={<Layout />}>
        <Route index element={<Dashboard />} />
        <Route path="features" element={<FeaturesPage />} />
        <Route path="tasks" element={<TasksPage />} />
        <Route path="logs" element={<WorkLogsPage />} />
      </Route>
    </Routes>
  );
}
