export const queryKeys = {
  projects: {
    all: ["projects"] as const,
    stats: (projectId: string) => ["projects", projectId, "stats"] as const,
  },
  features: {
    list: (projectId: string, status?: string) =>
      ["features", projectId, ...(status ? [{ status }] : [])] as const,
  },
  tasks: {
    list: (projectId: string, status?: string, priority?: string) =>
      ["tasks", projectId, ...(status || priority ? [{ status, priority }] : [])] as const,
  },
  workLogs: {
    list: (projectId: string) => ["workLogs", projectId] as const,
  },
  system: {
    info: ["system", "info"] as const,
    loops: ["system", "loops"] as const,
  },
};
